@@ -25,7 +25,6 @@ import logging
 import os
 
 from guessit import PY2, u, guess_file_info, __version__
-from guessit.plugins import transformers
 from guessit.options import get_opts
 from guessit.__version__ import __version__
 
@@ -45,7 +44,7 @@ def guess_file(filename, info='filename', options=None, **kwargs):
             pass
 
     if options.get('show_property'):
-        print (guess.get(options.get('show_property'), ''))
+        print(guess.get(options.get('show_property'), ''))
         return
 
     if options.get('yaml'):
@@ -53,7 +52,7 @@ def guess_file(filename, info='filename', options=None, **kwargs):
         for k, v in guess.items():
             if isinstance(v, list) and len(v) == 1:
                 guess[k] = v[0]
-        ystr = yaml.safe_dump({filename: dict(guess)}, default_flow_style=False)
+        ystr = yaml.safe_dump({filename: dict(guess)}, default_flow_style=False, allow_unicode=True)
         i = 0
         for yline in ystr.splitlines():
             if i == 0:
@@ -62,7 +61,7 @@ def guess_file(filename, info='filename', options=None, **kwargs):
                 print(":" + yline[1:])
             else:
                 print(yline)
-            i = i + 1
+            i += 1
         return
     print('GuessIt found:', guess.nice_string(options.get('advanced')))
 
@@ -70,6 +69,8 @@ def guess_file(filename, info='filename', options=None, **kwargs):
 def _supported_properties():
     all_properties = defaultdict(list)
     transformers_properties = []
+
+    from guessit.plugins import transformers
     for transformer in transformers.all_transformers():
         supported_properties = transformer.supported_properties()
         transformers_properties.append((transformer, supported_properties))
@@ -81,7 +82,7 @@ def _supported_properties():
             for property_name in supported_properties:
                 all_properties[property_name] # just make sure it exists
 
-    return (all_properties, transformers_properties)
+    return all_properties, transformers_properties
 
 
 def display_transformers():
@@ -139,8 +140,7 @@ def run_demo(episodes=True, movies=True, options=None):
                    'Series/Simpsons/The_simpsons_s13e18_-_i_am_furious_yellow.mpg',
                    'Series/Simpsons/Saison 12 Français/Simpsons,.The.12x08.A.Bas.Le.Sergent.Skinner.FR.[tvu.org.ru].avi',
                    'Series/Dr._Slump_-_002_DVB-Rip_Catalan_by_kelf.avi',
-                   'Series/Kaamelott/Kaamelott - Livre V - Second Volet - HD 704x396 Xvid 2 pass - Son 5.1 - TntRip by Slurm.avi'
-                   ]
+                   'Series/Kaamelott/Kaamelott - Livre V - Second Volet - HD 704x396 Xvid 2 pass - Son 5.1 - TntRip by Slurm.avi']
 
         for f in testeps:
             print('-' * 80)
@@ -152,8 +152,8 @@ def run_demo(episodes=True, movies=True, options=None):
                       'Movies/Blade Runner (1982)/Blade.Runner.(1982).(Director\'s.Cut).CD1.DVDRip.XviD.AC3-WAF.avi',
                       'Movies/Dark City (1998)/Dark.City.(1998).DC.BDRip.720p.DTS.X264-CHD.mkv',
                       'Movies/Sin City (BluRay) (2005)/Sin.City.2005.BDRip.720p.x264.AC3-SEPTiC.mkv',
-                      'Movies/Borat (2006)/Borat.(2006).R5.PROPER.REPACK.DVDRip.XviD-PUKKA.avi',  # FIXME: PROPER and R5 get overwritten
-                      '[XCT].Le.Prestige.(The.Prestige).DVDRip.[x264.HP.He-Aac.{Fr-Eng}.St{Fr-Eng}.Chaps].mkv',  # FIXME: title gets overwritten
+                      'Movies/Borat (2006)/Borat.(2006).R5.PROPER.REPACK.DVDRip.XviD-PUKKA.avi',
+                      '[XCT].Le.Prestige.(The.Prestige).DVDRip.[x264.HP.He-Aac.{Fr-Eng}.St{Fr-Eng}.Chaps].mkv',
                       'Battle Royale (2000)/Battle.Royale.(Batoru.Rowaiaru).(2000).(Special.Edition).CD1of2.DVDRiP.XviD-[ZeaL].avi',
                       'Movies/Brazil (1985)/Brazil_Criterion_Edition_(1985).CD2.English.srt',
                       'Movies/Persepolis (2007)/[XCT] Persepolis [H264+Aac-128(Fr-Eng)+ST(Fr-Eng)+Ind].mkv',
@@ -172,8 +172,9 @@ def run_demo(episodes=True, movies=True, options=None):
             print('-' * 80)
             guess_file(f, options=options, type='movie')
 
+
 def submit_bug(filename, options):
-    import requests # only import when needed
+    import requests  # only import when needed
     from requests.exceptions import RequestException
 
     try:
@@ -192,11 +193,10 @@ def submit_bug(filename, options):
         print('Could not submit bug at the moment, please try again later.')
 
 
-
 def main(args=None, setup_logging=True):
     if setup_logging:
         from guessit import slogging
-        slogging.setupLogging()
+        slogging.setup_logging()
 
     if PY2:  # pragma: no cover
         import codecs
@@ -213,10 +213,12 @@ def main(args=None, setup_logging=True):
         # Wrap sys.stdout into a StreamWriter to allow writing unicode.
         sys.stdout = codecs.getwriter(locale.getpreferredencoding())(sys.stdout)
 
+    from guessit.plugins import transformers
+
     if args:
-        options, args = get_opts().parse_args(args)
+        options = get_opts().parse_args(args)
     else:  # pragma: no cover
-        options, args = get_opts().parse_args()
+        options = get_opts().parse_args()
     if options.verbose:
         logging.getLogger().setLevel(logging.DEBUG)
 
@@ -252,8 +254,8 @@ def main(args=None, setup_logging=True):
             print('PyYAML not found. Using default output.')
 
     filenames = []
-    if args:
-        filenames.extend(args)
+    if options.filename:
+        filenames.extend(options.filename)
     if options.input_file:
         input_file = open(options.input_file, 'r')
         try:
@@ -261,7 +263,7 @@ def main(args=None, setup_logging=True):
         finally:
             input_file.close()
 
-    filenames = filter(lambda filename: filename, filenames)
+    filenames = filter(lambda f: f, filenames)
 
     if filenames:
         help_required = False
@@ -274,7 +276,6 @@ def main(args=None, setup_logging=True):
                            info=options.info.split(','),
                            options=vars(options))
 
-
     if help_required:  # pragma: no cover
         get_opts().print_help()
 
