@@ -24,6 +24,10 @@ from guessit.plugins.transformers import Transformer
 from guessit.matcher import GuessFinder
 import re
 
+_DIGIT = 0
+_LETTER = 1
+_OTHER = 2
+
 
 class GuessIdnumber(Transformer):
     def __init__(self):
@@ -42,21 +46,19 @@ class GuessIdnumber(Transformer):
             switch_letter_count = 0;
             letter_count = 0;
             last_letter = None
-            DIGIT = 0
-            LETTER = 1
-            OTHER = 2
-            last = LETTER
+
+            last = _LETTER
             for c in result['idNumber']:
                 if c in '0123456789':
-                    ci = DIGIT
+                    ci = _DIGIT
                 elif c in 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ':
-                    ci = LETTER
+                    ci = _LETTER
                     if c != last_letter:
                         switch_letter_count += 1
                     last_letter = c
                     letter_count += 1
                 else:
-                    ci = OTHER
+                    ci = _OTHER
 
                 if ci != last:
                     switch_count += 1
